Struct Smdmaen
Source #[repr(transparent)]
pub struct Smdmaen(pub u16);
Capture X0 FIFO DMA Enable.
Capture X0 FIFO DMA Enable.
Capture X1 FIFO DMA Enable.
Capture X1 FIFO DMA Enable.
Capture B0 FIFO DMA Enable.
Capture B0 FIFO DMA Enable.
Capture B1 FIFO DMA Enable.
Capture B1 FIFO DMA Enable.
Capture A0 FIFO DMA Enable.
Capture A0 FIFO DMA Enable.
Capture A1 FIFO DMA Enable.
Capture A1 FIFO DMA Enable.
Capture DMA Enable Source Select.
Capture DMA Enable Source Select.
FIFO Watermark AND Control.
FIFO Watermark AND Control.
Value Registers DMA Enable.
Value Registers DMA Enable.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.